==> dna-0.4.0.tar.gz: example/libc_example.dart <==
//  Copyright 2016 root.ext@gmail.com
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import '../lib/dna.dart';
import 'dart:typed_data';

@Struct()
class Process {
  @Field(C_INT)
  int id;

  @Field(C_INT)
  int parentId;
}

@Library('libc.so.6')
class Libc {
  dynamic lib = new DynamicLibrary<Libc>();

  int getpid() { return lib.getpid(); }
  int getuid() { return lib.getuid(); }
  int getgid() { return lib.getgid(); }

  @Param(C_INT)
  int getgroups (int count, @Param(LISTINT, out: true) Ref<List<int>> groups) { return lib.getgroups(count, groups); }

  int rand() { return lib.rand(); }
  int rand_r(@Param(TYPEDDATA) TypedData seedp) { return lib.rand_r(seedp); }
  void srand(@Param(C_UINT) int seed) { return lib.srand(seed); }
}

void main(){
  Libc libc = new Libc();
  var processId = libc.getpid();
  print('pid $processId');

  var userId = libc.getuid();
  print('user id ${userId}');

  var groupId = libc.getgid();
  print('group id ${groupId}');

  var n = libc.getgroups(0, new Ref(new List()));
  var groups = new Ref<List<int>>(new List<int>(n));
  libc.getgroups(n, groups);
  print('groups ${groups.value}');

  libc.srand(0xDEADBEEF);
  var rand = libc.rand();
  print('random $rand');

  var seed = new Uint32List.fromList([0xDEADBEEF]);
  var srand = libc.rand_r(seed);
  print('random with seed $srand');

}

==> dna-0.5.0.tar.gz: example/libc_example.dart <==
//  Copyright 2016 root.ext@gmail.com
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import 'dart:typed_data';

import '../lib/dna.dart';

@Struct()
class Process {
  @Field(C_INT)
  int id;

  @Field(C_INT)
  int parentId;
}

@Library('libc.so.6')
class Libc {
  dynamic lib = new DynamicLibrary<Libc>();

  int getpid() { return lib.getpid(); }
  int getuid() { return lib.getuid(); }
  int getgid() { return lib.getgid(); }

  @Param(C_INT)
  int getgroups (int count, @Param(C_INT, out: true, list: true) Ref<List<int>> groups) { return lib.getgroups(count, groups); }

  int rand() { return lib.rand(); }
  int rand_r(@Param(TYPEDDATA) TypedData seedp) { return lib.rand_r(seedp); }
  void srand(@Param(C_UINT) int seed) { return lib.srand(seed); }
}

void main(){
  Libc libc = new Libc();
  var processId = libc.getpid();
  print('pid $processId');

  var userId = libc.getuid();
  print('user id ${userId}');

  var groupId = libc.getgid();
  print('group id ${groupId}');

  var n = libc.getgroups(0, new Ref(new List()));
  var groups = new Ref<List<int>>(new List<int>.filled(n, 0));
  libc.getgroups(n, groups);
  print('groups ${groups.value}');

  libc.srand(0xDEADBEEF);
  var rand = libc.rand();
  print('random $rand');

  var seed = new Uint32List.fromList([0xDEADBEEF]);
  var srand = libc.rand_r(seed);
  print('random with seed $srand');

}
